==> ugene_1.12.3+dfsg.orig.tar.xz: ugene-1.12.3+dfsg.orig/src/plugins/biostruct3d_view/src/VanDerWaalsGLRenderer.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
#define _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_

#include "BioStruct3DGLRender.h"

namespace U2 { 

class VanDerWaalsGLRenderer : public BioStruct3DGLRenderer {
protected:
    VanDerWaalsGLRenderer(const BioStruct3D& struc, const BioStruct3DColorScheme* s, const QList<int> &shownModels, const BioStruct3DRendererSettings *settings);

public:
    void drawBioStruct3D();
    virtual void create() {};

    virtual void updateColorScheme() {};
    virtual void updateShownModels() {};
    virtual void updateSettings() {};

private:
    void drawAtoms(const BioStruct3DColorScheme* s);

    RENDERER_FACTORY(VanDerWaalsGLRenderer)
};

} //namespace

#endif // _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_

==> ugene_1.25.0+dfsg.orig.tar.xz: ugene-1.25.0/src/plugins/biostruct3d_view/src/VanDerWaalsGLRenderer.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
#define _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_

#include "BioStruct3DGLRender.h"

namespace U2 {

class VanDerWaalsGLRenderer : public BioStruct3DGLRenderer {
protected:
    VanDerWaalsGLRenderer(const BioStruct3D& struc, const BioStruct3DColorScheme* s, const QList<int> &shownModels, const BioStruct3DRendererSettings *settings);

public:
    void drawBioStruct3D();
    virtual void create() {}

    virtual void updateColorScheme() {}
    virtual void updateShownModels() {}
    virtual void updateSettings() {}

private:
    void drawAtoms(const BioStruct3DColorScheme* s);

    RENDERER_FACTORY(VanDerWaalsGLRenderer)
};

} //namespace

#endif // _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
